unit ICCAPIGlue;

(* Start Header *)

(* File:         ICCAPI.p (impl)
 * Generated by: 1.0d5
 * For:          IC 1.4
 * On:           Sunday, 14 September 1997, 21:17:55
 * 
 * This file is part of the Internet Configuration system and
 * is placed in the public domain for the benefit of all.
 *)

(* End Header *)

(* This file contains the component Start and Stop glue.  This glue is
	responsible for opening and close the component.  This code can
	be called by clients directly (clients who call ICCStart/ICCStop)
	or by the switch glue.
	
	The interface also contains a copy of the ICCAPI, although I'm
	not 100% sure why.  Certainly, it doesn't appear to hurt.  Because
	they are component routines, they go entirely through inlines.

	Also, the bulk of this interface is generated automatically.
*)

interface

	uses
		Types, 
		Files, 
		QuickDraw, 
		AppleTalk, 
		Aliases, 
		Components;

	type
		ICInstance = ComponentInstance;
		ICError = ComponentResult;
		
	function ICCStart (var inst: ComponentInstance; creator: OSType): ICError;
	function ICCStop (inst: ComponentInstance): ICError;
	function ICStart (var inst: ICInstance; creator: OSType): ICError;
	function ICStop (inst: ICInstance): ICError;
	function ICGetComponentInstance (inst: ICInstance; var componentInst: univ Ptr): ICError;

implementation

	uses
		GestaltEqu, 
		Errors;
		
	(* These two inlines allow ICCStart and ICCStop to call the component's
		start and stop routines.  Because we only expose the glue to general
		clients, there is no direct way for general clients to call the
		components Start and Stop routine, so instead we have to define it here.
	*)

	function ICCStartComponent (inst: ComponentInstance; creator: OSType): ICError;
		inline
			$2F3C, 4, 0, $7000, $A82A;
	function ICCStopComponent (inst: ComponentInstance): ICError;
		inline
			$2F3C, 0, 1, $7000, $A82A;

	function ICCStart (var inst: ComponentInstance; creator: OSType): ICError;
		(* This routine tests for the presence of Component Manager.  If
			it's available, it calls it to open a instance of the IC component.
			If that succeeds, it calls the component's Start routine.
		*)
		var
			err : ICError;
			junk: ICError;
			junkResponse: longint;
	begin
		inst := nil;
		if Gestalt(gestaltComponentMgr, junkResponse) = noErr then begin
			(* Do not attempt to use ICCAPI.p to pick up the symbolic
				constants for these OSTypes.  If you do, the build will
				fail because all the API routines declared in the interface
				are duplicates of those in ICCAPI.p.
			*)
			inst := OpenDefaultComponent('PREF', 'ICAp');
		end; (* if *)
		if inst = nil then begin
			err := badComponentInstance;
		end else begin
			err := ICCStartComponent(inst, creator);
			if err <> noErr then begin
				junk := CloseComponent(inst);
				inst := nil;
			end; (* if *)
		end; (* if *)
		ICCStart := err;
	end; (* ICCStart *)

	function ICCStop (inst: ComponentInstance): ICError;
		(* This routine will only be called if ICCStart succeeds, so
			it's safe to assume that Component Manager is available.
			It's a simple routine that Stops the component and then
			closes the instance.
		*)
		var
			err : ICError;
			err2: ICError;
	begin
		err := ICCStopComponent(inst);
		err2 := CloseComponent(inst);
		if err = noErr then begin
			err := err2;
		end; (* if *)
		ICCStop := err;
	end; (* ICCStop *)

	function ICStart (var inst: ICInstance; creator: OSType): ICError;
	begin
		ICStart := ICCStart(inst, creator);
	end; (* ICStart *)

	function ICStop (inst: ICInstance): ICError;
	begin
		ICStop := ICCStop(inst);
	end; (* ICStop *)

	function ICGetComponentInstance (inst: ICInstance; var componentInst: univ Ptr): ICError;
		(* GetComponentInstance is another special case routine because it's
			only available to clients using the ICAPI.  The implementaion is
			rather trivial.
		*)
	begin
		componentInst := Ptr(inst);
		if componentInst = nil then begin
			ICGetComponentInstance := badComponentInstance;
		end else begin
			ICGetComponentInstance := noErr;
		end; (* if *)
	end; (* ICGetComponentInstance *)

	function ICCGetComponentInstance (inst: ICInstance; var componentInst: univ Ptr): ICError;
		(* GetComponentInstance is another special case routine because it's
			only available to clients using the ICAPI.  The implementaion is
			rather trivial.
		*)
	begin
		componentInst := Ptr(inst);
		if componentInst = nil then begin
			ICCGetComponentInstance := badComponentInstance;
		end else begin
			ICCGetComponentInstance := noErr;
		end; (* if *)
	end; (* ICCGetComponentInstance *)

end. (* ICCAPIGlue *)
